@@ -61,6 +61,12 @@ class CreateCapacityReservationRequest(RpcRequest):
 	def set_Platform(self,Platform):
 		self.add_query_param('Platform',Platform)
 
+	def get_ResourceGroupId(self):
+		return self.get_query_params().get('ResourceGroupId')
+
+	def set_ResourceGroupId(self,ResourceGroupId):
+		self.add_query_param('ResourceGroupId',ResourceGroupId)
+
 	def get_PrivatePoolOptionsMatchCriteria(self):
 		return self.get_query_params().get('PrivatePoolOptions.MatchCriteria')
 
@@ -73,6 +79,16 @@ class CreateCapacityReservationRequest(RpcRequest):
 	def set_InstanceType(self,InstanceType):
 		self.add_query_param('InstanceType',InstanceType)
 
+	def get_Tags(self):
+		return self.get_query_params().get('Tag')
+
+	def set_Tags(self, Tags):
+		for depth1 in range(len(Tags)):
+			if Tags[depth1].get('Key') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tags[depth1].get('Key'))
+			if Tags[depth1].get('Value') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tags[depth1].get('Value'))
+
 	def get_EndTimeType(self):
 		return self.get_query_params().get('EndTimeType')
 
