@@ -79,6 +79,12 @@ class RunCommandRequest(RpcRequest):
 	def set_ContentEncoding(self,ContentEncoding):
 		self.add_query_param('ContentEncoding',ContentEncoding)
 
+	def get_RepeatMode(self):
+		return self.get_query_params().get('RepeatMode')
+
+	def set_RepeatMode(self,RepeatMode):
+		self.add_query_param('RepeatMode',RepeatMode)
+
 	def get_WindowsPasswordName(self):
 		return self.get_query_params().get('WindowsPasswordName')
 
